@@ -91,7 +91,7 @@ QUrl SageBackend::helpUrl() const
         return localDoc;
     else
     return QUrl(i18nc("the url to the documentation of Sage, please check if there is a translated version and use the correct url",
-                 "http://doc.sagemath.org/html/en/reference/index.html"));
+                 "https://doc.sagemath.org/html/en/reference/index.html"));
 }
 
 QString SageBackend::description() const
